summary refs log tree commit
path: root/lib/rack/lint.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/rack/lint.rb')
-rwxr-xr-xlib/rack/lint.rb3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/rack/lint.rb b/lib/rack/lint.rb
index 85319439..89dd880b 100755
--- a/lib/rack/lint.rb
+++ b/lib/rack/lint.rb
@@ -56,9 +56,10 @@ module Rack
         @env[RACK_INPUT] = InputWrapper.new(@env[RACK_INPUT])
         @env[RACK_ERRORS] = ErrorWrapper.new(@env[RACK_ERRORS])
 
## and returns an Array of exactly three values:
         @response = @app.call(@env)
         raise LintError, "response is not an Array, but #{@response.class}" unless @response.kind_of? Array
+        raise LintError, "response is frozen" if @response.frozen?
         raise LintError, "response array has #{@response.size} elements instead of 3" unless @response.size == 3
 
         @status, @headers, @body = @response
@@ -56,9 +56,10 @@ module Rack
         @env[RACK_ERRORS] = ErrorWrapper.new(@env[RACK_ERRORS])
 
-        ## and returns an Array of exactly three values:
+        ## and returns a non-frozen Array of exactly three values:
         @response = @app.call(@env)
         raise LintError, "response is not an Array, but #{@response.class}" unless @response.kind_of? Array